@@ -1,5 +1,5 @@
 ##
-#  Copyright (c) 2009-2013 LabKey Corporation
+#  Copyright (c) 2009-2014 LabKey Corporation
 # 
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -54,11 +54,13 @@ header <- basicTextGatherer()
 handle <- getCurlHandle()
 headerFields <- c('Content-Type'="application/json;charset=utf-8")
 clist <- ifcookie()
-if(clist$Cvalue==1) {myopts <- curlOptions(cookie=paste(clist$Cname,"=",clist$Ccont, sep=""),
-                        writefunction=reader$update, headerfunction=header$update, ssl.verifyhost=FALSE,
-                        ssl.verifypeer=FALSE, followlocation=TRUE)} else
-{myopts <- curlOptions(netrc=1, writefunction=reader$update, headerfunction=header$update, ssl.verifyhost=FALSE,
-                        ssl.verifypeer=FALSE, followlocation=TRUE)}
+if(clist$Cvalue==1) {
+    myopts<- curlOptions(cookie=paste(clist$Cname,"=",clist$Ccont, sep=""), writefunction=reader$update, headerfunction=header$update,
+                        .opts=c(labkey.curlOptions()))
+} else {
+    myopts<- curlOptions(netrc=1, writefunction=reader$update, headerfunction=header$update,
+                        .opts=c(labkey.curlOptions()))
+}
 
 ## Support user-settable options for debuggin and setting proxies etc
 if(exists(".lksession"))
@@ -77,14 +79,14 @@ curlPerform(url=myurl, postFields=pbody, httpheader=headerFields, .opts=myopts,
 h <- parseHeader(header$value())
 status <- getCurlInfo(handle)$response.code
 message <- h$statusMessage
-if(status==500) {decode <- fromJSON2(reader$value()); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
+if(status==500) {decode <- fromJSON(reader$value()); message <- decode$exception; stop(paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))}
 
 if(status>=400)
 {
     contTypes <- which(names(h)=='Content-Type')
     if(length(contTypes)>0 && (tolower(h[contTypes[1]])=="application/json;charset=utf-8" || tolower(h[contTypes[2]])=="application/json;charset=utf-8"))
     {
-        decode <- fromJSON2(reader$value());
+        decode <- fromJSON(reader$value());
         message<-decode$exception;
         stop (paste("HTTP request was unsuccessful. Status code = ",status,", Error message = ",message,sep=""))
     } else
@@ -93,7 +95,7 @@ if(status>=400)
     }
 }
 
-newdata <- fromJSON2(reader$value())
+newdata <- fromJSON(reader$value())
 
 
 return(newdata)
